package
module
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jan 30, 2021
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 5
Opens a new window with list of known importers.
README
¶
debouncer
Golang Debouncer
Documentation
¶
type Debouncer struct {
}
Debouncer - A debouncer for ensuring that only one event fires when
multiple triggers happen inside a defined window of time
New - Returns a new debouncer with the defined delay and callback
Trigger - Calls the callback after duration of the last calling of trigger
Source Files
¶
Click to show internal directories.
Click to hide internal directories.